@CHARSET "UTF-8";

.masthead {
	background:rgb(234, 231, 215);
	border:solid rgb(0, 0, 155) 0px;
	border-bottom-width: .05em;
}
.masthead .mastheadLeft ul, .masthead .mastheadRight ul {
	border:solid rgb(215, 215, 215) 0px;
	color: rgb(138, 136, 127);
}
.masthead .mastheadLeft ul li a, .masthead .mastheadRight ul li a {
	color:rgb(138, 136, 127);
}
.masthead #conddb a{
	color:white;
	background:rgb(75, 98, 221);
}
/* This next bit is for site dependant masthead */
.mastheadfooter {
	background:rgb(75, 98, 221);
}
.mastheadfooter ul{
	color:white;
}
.mastheadfooter ul li {
	color:white;
}
.mastheadfooter ul li a, .mastheadfooter ul li a:visited {
	color:white;
}
.mastheadfooter ul li a:hover {
	color:white;
}
.mastheadfooter ul li a:active {
	color:white;
}